class AimTrainer {
    constructor() {
        this.score = 0;
        this.shots = 0;
        this.hits = 0;
        this.isPlaying = false;
        this.timeLeft = 30;
        this.targetArea = document.getElementById('target-area');
        this.target = document.getElementById('target');
        this.scoreElement = document.getElementById('score');
        this.accuracyElement = document.getElementById('accuracy');
        this.timerElement = document.getElementById('timer');
        this.startBtn = document.getElementById('start-btn');
        this.difficultySelect = document.getElementById('difficulty');
        
        this.initializeEventListeners();
    }

    initializeEventListeners() {
        this.startBtn.addEventListener('click', () => this.startGame());
        this.targetArea.addEventListener('click', (e) => this.handleShot(e));
        this.target.addEventListener('click', (e) => {
            e.stopPropagation();
            this.handleHit();
        });
    }

    startGame() {
        this.reset();
        this.isPlaying = true;
        this.startBtn.disabled = true;
        this.moveTarget();
        this.startTimer();
    }

    reset() {
        this.score = 0;
        this.shots = 0;
        this.hits = 0;
        this.timeLeft = 30;
        this.updateUI();
    }

    handleShot(e) {
        if (!this.isPlaying) return;
        this.shots++;
        this.updateAccuracy();
    }

    handleHit() {
        if (!this.isPlaying) return;
        this.hits++;
        this.score += 100;
        this.shots++;
        this.updateUI();
        this.moveTarget();
        
        // Visual feedback
        this.target.style.transform = 'translate(-50%, -50%) scale(0.8)';
        setTimeout(() => {
            this.target.style.transform = 'translate(-50%, -50%) scale(1)';
        }, 100);
    }

    moveTarget() {
        const targetArea = this.targetArea.getBoundingClientRect();
        const targetSize = this.target.offsetWidth;
        
        const padding = targetSize / 2;
        const maxX = targetArea.width - padding;
        const maxY = targetArea.height - padding;
        
        const x = Math.random() * (maxX - padding) + padding;
        const y = Math.random() * (maxY - padding) + padding;
        
        this.target.style.left = `${x}px`;
        this.target.style.top = `${y}px`;
    }

    updateUI() {
        this.scoreElement.textContent = this.score;
        this.updateAccuracy();
        this.timerElement.textContent = this.timeLeft;
    }

    updateAccuracy() {
        const accuracy = this.shots === 0 ? 0 : Math.round((this.hits / this.shots) * 100);
        this.accuracyElement.textContent = accuracy;
    }

    startTimer() {
        const timer = setInterval(() => {
            this.timeLeft--;
            this.timerElement.textContent = this.timeLeft;
            
            if (this.timeLeft <= 0) {
                clearInterval(timer);
                this.endGame();
            }
        }, 1000);
    }

    endGame() {
        this.isPlaying = false;
        this.startBtn.disabled = false;
        alert(`Game Over!\nFinal Score: ${this.score}\nAccuracy: ${this.accuracyElement.textContent}%`);
    }
}

document.addEventListener('DOMContentLoaded', () => {
    const game = new AimTrainer();
});
